==> datatables-core-0.10.1-sources.jar: com/github/dandelion/datatables/core/export/ReservedFormat.java <==
/*
 * [The "BSD licence"]
 * Copyright (c) 2013-2014 Dandelion
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.github.dandelion.datatables.core.export;

/**
 * All constants declared here represents a display format that is used in
 * multiple ways:
 * <ul>
 * <li>First, to identify reserved words when export is enabled for a table. As
 * soon as one of these reserved words is used, some configuration will be
 * applied by default.</li>
 * <li>
 * But it is also used to decide whether a format should appear in the processed
 * template (HTML page, export file).</li>
 * </ul>
 * 
 * @author Thibault Duchateau
 * @since 0.10.0
 * @see ExportConf
 */
public final class ReservedFormat {

	public static final String ALL = "all";
	public static final String HTML = "html";
	public static final String CSV = "csv";
	public static final String XML = "xml";
	public static final String PDF = "pdf";
	public static final String XLS = "xls";
	public static final String XLSX = "xlsx";

	/**
	 * Prevent instantiation.
	 */
	private ReservedFormat() {
	}
}

==> datatables-core-1.1.0-sources.jar: com/github/dandelion/datatables/core/export/ReservedFormat.java <==
/*
 * [The "BSD licence"]
 * Copyright (c) 2013-2015 Dandelion
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.github.dandelion.datatables.core.export;

/**
 * All constants declared here represents a display format that is used in
 * multiple ways:
 * <ul>
 * <li>First, to identify reserved words when export is enabled for a table. As
 * soon as one of these reserved words is used, some configuration will be
 * applied by default.</li>
 * <li>But it is also used to decide whether a format should appear in the
 * processed template (HTML page, export file).</li>
 * </ul>
 * 
 * @author Thibault Duchateau
 * @since 0.10.0
 * @see ExportConf
 */
public final class ReservedFormat {

   public static final String ALL = "all";
   public static final String HTML = "html";
   public static final String CSV = "csv";
   public static final String XML = "xml";
   public static final String PDF = "pdf";
   public static final String XLS = "xls";
   public static final String XLSX = "xlsx";

   /**
    * Prevent instantiation.
    */
   private ReservedFormat() {
   }
}
